@@ -36,7 +36,9 @@ class ScoringFunctionComponentNameEnum:
     RH_CLINT_PIP = "rh-clint"
     SOLUBILITY_DD_PIP = "solubility-dd"
     HERG_PIP = "herg"
+    RAT_PK_PIP = "pip-rat-pk"
     REACTION_FILTERS = "reaction_filters"
+    CLAB_TOP_20 = "clab_top_20"
 
     def __getattr__(self, name):
         if name in self:
